#!/bin/sh
# commenttool.sh - script to run CommentTool under Linux/Unix with an 
#                  appropriate classpath.  If first parameter is -v, 
#                  will output java command line before running it.

appname="CommentTool2"

# Find out the directory where this script is,
# so we can find the application files underneath it.
scriptpath=`dirname $0`
scriptname=`basename $0`
cwd=`pwd`

if [ "$scriptpath" = "." -o "$scriptpath" = "" ] ; then
	scriptpath=$cwd
fi

cd ${scriptpath}

if [ -f "$scriptpath/$appname.jar" ] ; then
	chmod 755 $scriptpath/$appname.jar
	# Invoke the executable jar.
	echo "Running $appname Jar..."
	$scriptpath/CommentTool2.jar&
elif [ -f "$scriptpath/bin/$appname.class" ] ; then
	# Alternate invocation.
	echo "Running $appname Class..."

	# classpath must contain paths to all needed classes for CommentTool,
	# separated by colons.    All .jar files under lib/
	# below the directory the .sh file is in are automatically added.
	# If you need others, either drop them in that directory, or add 
	# them here manually (dropping them in the directory is better!).
	ctclasspath=:/usr/lib/jvm/java-6-openjdk-i386/jre/lib:${scriptpath}/bin:${scriptpath}/lib/sqlite-jdbc-3.7.2.jar

	for l in ${scriptpath}/lib/*.jar ; do
		ctclasspath=$ctclasspath:$l
	done

	# Output what we will execute, for debugging, if we have a -v switch
	if [ "$1" = "-v" ] ; then
		shift
		echo java -classpath "$ctclasspath" -Dswing.aatext=true $appname $*
	fi

	# Run the relevant Java code with the appropriate classpath
	java -classpath "$ctclasspath" -Dswing.aatext=true $appname $*&

else
	echo "$scriptname: $appname Not Found!"
	exit
fi
